# Data Parser for Universal ascii lightning format ⚡
<br>
Python class that allows for a python requests response received in the universal ascii lightning format to be parsed to a pandas dataframe object.
<br><br>

Publicly available lightning data though MET Norway and Swedish SMHI are returned in the universal ascii lightning format. <br>The purpose of this Python project is to easily parse that data into a pandas dataframe (and numpy array).
<br>

PyPI link: https://pypi.org/project/UALF-dataframe-parser/0.0.1/

<br>
A visualisation of the format can be found on MET Norway's Frost API resource pages:

![ualf](https://frost.met.no/images/concepts/UALF_format.png)
